@@ -624,19 +624,35 @@ class BlockVolume(volume.Volume):
             self.log.warning("cannot finalize parent volume %s", puuid,
                              exc_info=True)
 
-        try:
-            try:
-                lvm.removeLVs(self.sdUUID, self.volUUID)
-            except se.CannotRemoveLogicalVolume:
-                # At this point LV is already marked as illegal, we will
-                # try to cleanup whatever we can...
-                pass
+        # Basically, we want to mark the volume _remove_me at the beginning of
+        # the delete; however, with the current delete logic, if marking the
+        # volume fails, and the deleted volume is a leaf, we end up with a
+        # chain with a valid leaf volume.
+        # The ultimate solution of volume deletion requires changes in
+        # image.syncVolumeChain to disconnect the volume from the chain,
+        # and probably there mark it as _remove_me.
+        manifest = sdCache.produce_manifest(self.sdUUID)
+        manifest.markForDelVols(self.sdUUID, self.imgUUID, [self.volUUID],
+                                sc.REMOVED_IMAGE_PREFIX)
 
-            self.removeMetadata([self.sdUUID, offs])
-        except Exception as e:
-            eFound = e
-            self.log.error("cannot remove volume %s/%s", self.sdUUID,
-                           self.volUUID, exc_info=True)
+        try:
+            lvm.removeLVs(self.sdUUID, self.volUUID)
+        except se.CannotRemoveLogicalVolume as e:
+            self.log.exception("Failed to delete volume %s/%s. The "
+                               "logical volume must be removed manually.",
+                               self.sdUUID, self.volUUID)
+        else:
+            # If removing the LV fails, we don't want to remove the
+            # metadata. As the volume still exists on the storage, and is
+            # accessible, removing the metadata will cause unexpected
+            # errors when accessing the metadata that was wiped.  This is a
+            # minimal solution for: https://bugzilla.redhat.com/1574631
+            try:
+                self.removeMetadata([self.sdUUID, offs])
+            except se.VolumeMetadataWriteError as e:
+                eFound = e
+                self.log.exception("Failed to delete volume %s/%s metadata.",
+                                   self.sdUUID, self.volUUID)
 
         try:
             self.log.info("Unlinking %s", vol_path)
